`map.set_key`

Set a key to a specific value in a map.
We represent maps as Arrays of Key/Value structs:
`ARRAY<STRUCT<key ANY TYPE, value ANY TYPE>>`.

The type of the key and value you are setting must
match the types in the map itself.
